Change Log
##########

..
   All enhancements and patches to skill_tagging will be documented
   in this file.  It adheres to the structure of https://keepachangelog.com/ ,
   but in reStructuredText instead of Markdown (for ease of incorporation into
   Sphinx documentation and the PyPI description).

   This project adheres to Semantic Versioning (https://semver.org/).

.. There should always be an "Unreleased" section for changes pending release.

Unreleased
**********

*

[0.1.3] - 2023-09-27
************************************************

Changed
=======

* Gate skills API call behind probablity check to reduce traffic.


[0.1.2] - 2023-08-18
************************************************

Added
=====

* Define Metaclass for XblockSkillTagging Mixin


[0.1.1] - 2023-06-14
************************************************

Added
=====

* Add temporary option to configure topic name for skill-verified event.

[0.1.0] - 2022-12-01
************************************************

Added
=====

* First release on PyPI.
